//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

#define USING_OPENAPI_GENERATOR // alt. is Swagger

using System.IO;
using System.Collections.Generic;
using UnityEngine;

#if USING_OPENAPI_GENERATOR
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Model;
#else
using IO.Swagger.Api;
using IO.Swagger.Model;
#endif

#if UNITY_EDITOR
namespace ETSI.ARF.WorldStorage.RESTful
{
    public class RESTfulTrackableRequest
    {
        #region ##### Trackable Requests #####
        static public List<Trackable> GetAllTrackables(WorldStorageSettings ws)
        {
            string uri = ws.basePath + ":" + ws.port.ToString();
            TrackablesApi api = new TrackablesApi(uri);

            List<Trackable> result = api.GetTrackables();
            return result;
        }

        static public Trackable GetTrackable(WorldStorageSettings ws, string uuid)
        {
            string uri = ws.basePath + ":" + ws.port.ToString();
            TrackablesApi api = new TrackablesApi(uri);

            Trackable result = api.GetTrackableById(uuid);
            return result;
        }

        static public void DeleteTrackable(WorldStorageSettings ws, string uuid)
        {
            string uri = ws.basePath + ":" + ws.port.ToString();
            TrackablesApi api = new TrackablesApi(uri);
            api.DeleteTrackable(uuid);
        }

        static public Trackable TrackableFromStrings(string guid, string creatorUID)
        {
            EncodingInformationStructure trackableEncodingInformation =
                new EncodingInformationStructure(EncodingInformationStructure.DataFormatEnum.ARCORE, "1.0");
            Debug.Log("Created encoding information");

#if USING_OPENAPI_GENERATOR
            List<double> trackableDimension = new List<double>();
#else
    List<double?> trackableDimension = new List<double?>();
#endif
            trackableDimension.Add(5);
            trackableDimension.Add(5);
            Debug.Log("created dimension");

            byte[] bytes = new byte[100];

            for (int i = 0; i < bytes.Length; i++)
            {
                bytes[i] = (byte)i;
            }

            List<float> crs = new List<float>
            {
                -2,    1,    -3,    4,
                4,    4,    4,    2,
                1,    0,    -2,    1,
                -1,    -2,    0,    0
            };

            Dictionary<string, List<string>> kv = new Dictionary<string, List<string>>();
            kv.Add("Scenario", new List<string> { "DTwin" });

            System.Guid _guid = System.Guid.Parse(guid); 
            Trackable t = new Trackable(
                _guid, 
                System.Guid.Parse(creatorUID), 
                Trackable.TrackableTypeEnum.IMAGEMARKER, 
                trackableEncodingInformation, 
                bytes,
                crs,
                Trackable.UnitSystemEnum.M,
                trackableDimension, 
                kv);
            t.UID = _guid;
            return t;
        }

        static public void PostAddTrackable(WorldStorageSettings ws, Trackable trackable)
        {
            string uri = ws.basePath + ":" + ws.port.ToString();

            Debug.Log("Posting Add Trackable to Server");
            TrackablesApi api = new TrackablesApi(uri);
            Debug.Log("Created Trackables API");

            
            string result = api.AddTrackable(trackable);

            Debug.Log(result);
        }
        #endregion
    }
}
#endif