//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

#define USING_OPENAPI_GENERATOR // alt. is Swagger

using System.IO;
using System.Collections.Generic;
using UnityEngine;

#if USING_OPENAPI_GENERATOR
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Model;
#else
using IO.Swagger.Api;
using IO.Swagger.Model;
#endif

#if UNITY_EDITOR
namespace ETSI.ARF.WorldStorage.RESTful
{
    public class RESTfulWorldAnchorRequest
    {
        #region ##### World Anchor Requests #####
        static public void PostAddWorldAnchor(WorldStorageSettings ws)
        {
            string uri = ws.basePath + ":" + ws.port.ToString();

            Debug.Log("Posting Add World Anchor to Server");
            WorldAnchorsApi api = new WorldAnchorsApi(uri);
            Debug.Log("Created World Anchors API");

            TrackableEncodingInformationStructure trackableEncodingInformation =
                new TrackableEncodingInformationStructure(TrackableEncodingInformationStructure.DataFormatEnum.ARCORE, "1.0");
            Debug.Log("Created encoding information");

            List<double?> trackableDimension = new List<double?>();
            trackableDimension.Add(5);
            trackableDimension.Add(5);
            Debug.Log("Created dimension");

            byte[] bytes = new byte[100];

            for (int i = 0; i < bytes.Length; i++)
            {
                bytes[i] = (byte)i;
            }

            string result = api.AddWorldAnchor("testCreatorUID", "METERS");

            Debug.Log(result);
        }
        #endregion
    }
}
#endif